<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>
<xsl:strip-space elements="*"/>

<xsl:include href="util.xslt"/>

<xsl:template match="/">
	<xsl:apply-templates select="resume"/>
</xsl:template>

<xsl:template match="resume">
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en-US" lang="en-US">
	<head>
	<xsl:apply-templates select="css"/>
	<title>
	<xsl:apply-templates select="name" mode="title"/>
	</title>
	</head>
	<body>
	<xsl:apply-templates select="logobar"/>
	<xsl:apply-templates select="sidebar"/>
	<div class="main">
	<xsl:apply-templates select="name" mode="body"/>
	<xsl:apply-templates select="address"/>
	<xsl:apply-templates select="section"/>
	<h5>
	References available upon request.
	</h5>
	</div>
	</body>
	</html>
</xsl:template>

<xsl:template match="logobar">
	<div class="logo">
	<xsl:apply-templates/>
	</div>
</xsl:template>

<xsl:template match="logoimage">
	<img src="{@src}" align="{@align}" alt="{@alt}"/>
</xsl:template>

<xsl:template match="logotext">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="sidebar">
	<div class="side">
	<xsl:apply-templates/>
	</div>
</xsl:template>

<xsl:template match="sidesection">
	<h1>
	<xsl:apply-templates/>
	</h1>
</xsl:template>

<xsl:template match="sideline">
	<h2>
	<xsl:apply-templates/>
	</h2>
</xsl:template>

<xsl:template match="name" mode="body">
	<div align="center">
	<h1>
	<xsl:apply-templates select="first"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="middle"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="last"/>
	</h1>
	</div>
</xsl:template>

<xsl:template match="css">
	<style type="text/css">
	<xsl:text>@import url('</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>');</xsl:text>
	</style>
</xsl:template>

<xsl:template match="name" mode="title">
	<xsl:apply-templates select="first"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="middle"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="last"/>
	<xsl:text>'s Resume</xsl:text>
</xsl:template>

<xsl:template match="first">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="middle">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="last">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="address">
	<div align="center">
	<xsl:apply-templates select="street"/>
	<br/>
	<xsl:apply-templates select="town"/>
	<xsl:text>, </xsl:text>
	<xsl:apply-templates select="state"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="zip"/>
	</div>
	<xsl:value-of select="$cr"/>
	<div align="center">
	<xsl:apply-templates select="phone"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="url"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="email"/>
	</div>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="street">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="town">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="state">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="zip">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="phone">
	<xsl:text>phone: </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="url">
	<xsl:text>www: </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="email">
	<xsl:text>email: </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="section">
	<h2>
	<xsl:value-of select="@name"/>
	</h2>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="entry"/>
</xsl:template>

<xsl:template match="entry">
	<h3>
	<xsl:apply-templates select="position"/>
	<xsl:apply-templates select="dates"/>
	</h3>
	<xsl:value-of select="$cr"/>
	<h4>
	<xsl:apply-templates select="employer"/>
	</h4>
	<xsl:apply-templates select="description"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="position">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="dates">
	<xsl:text>, </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="employer">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="description">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="para">
	<p>
	<xsl:apply-templates/>
	</p>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="itemizedlist">
	<ul>
	<xsl:apply-templates/>
	</ul>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="listitem">
	<li>
	<xsl:apply-templates/>
	</li>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="ulink">
	<a href="{@url}">
	<xsl:apply-templates/>
	</a>
</xsl:template>

</xsl:stylesheet>
