<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="text"/>
<xsl:strip-space elements="*"/>

<xsl:include href="util.xslt"/>

<xsl:template match="/">
	<xsl:apply-templates select="resume"/>
</xsl:template>

<xsl:template match="resume">
	<xsl:text>\documentclass[10pt,draft]{cjw-resume}
        \usepackage{cjwresize}
                \setlength{\textwidth}{6.5in}
                \setlength{\textheight}{10in}
        \resize
                                                                                
\begin{document}</xsl:text>
	<xsl:apply-templates select="name"/>
	<xsl:apply-templates select="address"/>
	<xsl:text>\maketitle</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="section"/>
	<xsl:value-of select="$cr"/>
	<xsl:text>\references</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<xsl:text>\end{document}</xsl:text>
</xsl:template>

<xsl:template match="name">
	<xsl:text>\name</xsl:text>
	<xsl:apply-templates select="first"/>
	<xsl:apply-templates select="middle"/>
	<xsl:apply-templates select="last"/>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="first">
	<xsl:text>{</xsl:text>
	<xsl:value-of select="."/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="middle">
	<xsl:text>{</xsl:text>
	<xsl:value-of select="."/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="last">
	<xsl:text>{</xsl:text>
	<xsl:value-of select="."/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="address">
	<xsl:text>\address{</xsl:text>
	<xsl:apply-templates select="street"/>
	<xsl:text> \\</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="town"/>
	<xsl:text>, </xsl:text>
	<xsl:apply-templates select="state"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="zip"/>
	<xsl:text> \\</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="phone"/>
	<xsl:text>}</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<xsl:text>\url{</xsl:text>
	<xsl:apply-templates select="url"/>
	<xsl:text>}</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<xsl:text>\email{</xsl:text>
	<xsl:apply-templates select="email"/>
	<xsl:text>}</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="street">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="town">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="state">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="zip">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="phone">
	<xsl:text>phone: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="url">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="email">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="section">
	<xsl:text>\section{</xsl:text>
	<xsl:value-of select="@name"/>
	<xsl:text>}</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="entry"/>
</xsl:template>

<xsl:template match="entry">
	<xsl:text>\begin{entry}</xsl:text>
	<xsl:text>{</xsl:text>
	<xsl:apply-templates select="position"/>
	<xsl:apply-templates select="dates"/>
	<xsl:text>} \\</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="employer"/>
	<xsl:apply-templates select="description"/>
	<xsl:text>\end{entry}</xsl:text>
	<xsl:value-of select="$cr"/>
	<!-- tempt LaTeX to break here so it doesn't happen inside entry -->
	<xsl:text>\pagebreak[3]</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="position">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="dates">
	<xsl:text>\hfill</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:text>{\it </xsl:text>
	<xsl:value-of select="."/>
	<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="employer">
	<xsl:call-template name="latex-safe">
		<xsl:with-param name="str" select="."/>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="description">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="para">
	<xsl:call-template name="fmt">
                <xsl:with-param name="str">
			<xsl:call-template name="latex-safe">
				<xsl:with-param name="str" select="."/>
			</xsl:call-template>
                </xsl:with-param>
                <xsl:with-param name="before">
                        <xsl:text></xsl:text>
                </xsl:with-param>
        </xsl:call-template>
	<xsl:text>\\</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="itemizedlist">
	<xsl:text>\begin{list}{$\bullet$}{\leftmargin 0.5in \parsep 0in}</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates/>
	<xsl:text>\end{list}</xsl:text>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="listitem">
	<xsl:text>\item </xsl:text>
	<xsl:apply-templates/>
	<xsl:value-of select="$cr"/>
</xsl:template>

</xsl:stylesheet>
